ExTwilio.Feedback
Represents a Call Feedback resource in the Twilio API.
Examples
Since Call Feedback is a nested resource in the Twilio API, you must pass in a parent Call SID to all functions in this module.
ExTwilio.Feedback.create([quality_score: 5], [call: "call_sid"])
ExTwilio.Feedback.find(call: "call_sid")
Summary
Find feedback for a given call. Any options other than [call: "sid"] will result in a FunctionClauseError
Underscored and lowercased collection name for a given resource. Delegates the real work to ExTwilio.Api.resource_collection_name/1 by default
CamelCase resource name as it would be used in Twilio's API. Delegates the real work to ExTwilio.Api.resource_name/1 by default
Functions
Specs
find([{:call, String.t}]) ::
ExTwilio.Parser.success |
ExTwilio.Parser.error
Find feedback for a given call. Any options other than [call: "sid"] will result in a FunctionClauseError.
Example
ExTwilio.Feedback.find(call: "sid")
%ExTwilio.Feedback{issues: [], quality_score: 5}
Underscored and lowercased collection name for a given resource. Delegates the real work to ExTwilio.Api.resource_collection_name/1 by default.
Override in your module before use ExTwilio.Resource if you need something different.